@@ -15,6 +15,7 @@ from hoppr_cyclonedx_models.cyclonedx_1_4 import Component
 from hoppr import __version__, plugin_utils
 from hoppr.base_plugins.hoppr import HopprPlugin, hoppr_process, hoppr_rerunner
 from hoppr.configs.credentials import Credentials
+from hoppr.hoppr_types.component_coverage import ComponentCoverage
 from hoppr.hoppr_types.cred_object import CredObject
 from hoppr.hoppr_types.purl_type import PurlType
 from hoppr.result import Result
@@ -26,6 +27,8 @@ class BaseCollectorPlugin(HopprPlugin):
     Base class for collector plugins
     """
 
+    default_component_coverage = ComponentCoverage.EXACTLY_ONCE
+
     def directory_for(
         self,
         purl_type: Union[str, PurlType],
