@@ -14,6 +14,7 @@ from packageurl import PackageURL  # type: ignore
 
 from hoppr import plugin_utils
 from hoppr.context import Context
+from hoppr.hoppr_types.component_coverage import ComponentCoverage
 from hoppr.mem_logger import MemoryLogger
 from hoppr.result import Result
 from hoppr.utils import obscure_passwords
@@ -164,6 +165,7 @@ class HopprPlugin(ABC):
 
     required_commands: List[str] = []
     supported_purl_types: List[str] = []
+    default_component_coverage = ComponentCoverage.OPTIONAL
 
     def __init__(
         self,
