@@ -44,6 +44,9 @@ class CollectMavenPlugin(SerialCollectorPlugin):
         Copy a component to the local collection directory structure
         """
         purl = PackageURL.from_string(comp.purl)
+        result = self.check_purl_specified_url(purl, repo_url)
+        if not result.is_success():
+            return result
 
         extension = purl.qualifiers.get("type", _DEFAULT_MAVEN_EXT)
 
@@ -89,8 +92,8 @@ class CollectMavenPlugin(SerialCollectorPlugin):
 
             command.extend(self.extra_opts)
 
-            result = self.run_command(command, password_list)
-            if result.returncode != 0:
+            run_result = self.run_command(command, password_list)
+            if run_result.returncode != 0:
                 msg = f"Failed to download maven artifact {purl.namespace}:{purl.name}:{purl.version} type={extension}"
                 self.get_logger().error(msg)
                 return Result.retry(msg)
@@ -116,8 +119,8 @@ class CollectMavenPlugin(SerialCollectorPlugin):
 
                 command.extend(self.extra_opts)
 
-                result = self.run_command(command, password_list)
-                if result.returncode != 0:
+                run_result = self.run_command(command, password_list)
+                if run_result.returncode != 0:
                     msg = f"Failed to download pom for maven artifact {purl.namespace}:{purl.name}:{purl.version}"
                     self.get_logger().error(msg)
                     return Result.retry(msg)
